@@ -18,9 +18,9 @@ def common_guilds(user: list, bot:list, permissions = 0x20):
     return [guild for guild in user if guild['id'] in map(lambda i: i['id'], bot) and (guild['permissions'] & permissions) == permissions]
 
 def permissions(user_guilds, guild_id, permissions = 0x20):
-    for server in guild_user:
+    for server in user_guilds:
         if int(server['id']) == int(guild_id):
-            if (int(serwer['permissions_new']) & int(permissions)) == permissions:
+            if (int(server['permissions_new']) & int(permissions)) == permissions:
                 return True
             else:
                 return False
